@@ -114,7 +114,7 @@ class ServiceUserForIAC(core.Construct):
                         "iam:PassRole",
                         "iam:DeleteAccessKey",
                         "rds:DescribeEngineDefaultParameters",
-                        "elasticfilesystem:*MountTarget",
+                        "elasticfilesystem:*MountTarget*",
                         "elasticfilesystem:DescribeFileSystems",
                         "ec2:*Volume*"
                     ],
